@@ -2,6 +2,7 @@ from typing import Any
 
 from .types import (
     BoolSchema,
+    BytesSchema,
     DictSchema,
     FloatSchema,
     GenericSchema,
@@ -29,5 +30,7 @@ def from_native(value: Any) -> GenericSchema:
         return ListSchema()([from_native(x) for x in value])
     elif isinstance(value, dict):
         return DictSchema()({key: from_native(val) for key, val in value.items()})
+    elif isinstance(value, bytes):
+        return BytesSchema()(value)
     else:
         raise ValueError(value)
