@@ -5,13 +5,16 @@ if TYPE_CHECKING:
     from .types import (
         AnySchema,
         BoolSchema,
+        BytesSchema,
         ConstSchema,
         DictSchema,
         FloatSchema,
+        GenericTypeAliasSchema,
         IntSchema,
         ListSchema,
         NoneSchema,
         StrSchema,
+        TypeAliasPropsType,
     )
 
 __all__ = ("SchemaVisitor", "SchemaVisitorReturnType",)
@@ -56,6 +59,15 @@ class SchemaVisitor(ABC, Generic[SchemaVisitorReturnType]):
     def visit_const(self, schema: "ConstSchema", **kwargs: Any) -> SchemaVisitorReturnType:
         pass
 
+    @abstractmethod
+    def visit_bytes(self, schema: "BytesSchema", **kwargs: Any) -> SchemaVisitorReturnType:
+        pass
+
+    @abstractmethod
+    def visit_type_alias(self, schema: "GenericTypeAliasSchema[TypeAliasPropsType]",
+                         **kwargs: Any) -> SchemaVisitorReturnType:
+        pass
+
     def __getattr__(self, name: Any) -> Any:
         raise AttributeError(f"{self.__class__.__name__!r} object has no attribute {name!r}")
 
