@@ -1,4 +1,4 @@
-from typing import Any, Dict, KeysView, Tuple
+from typing import Any, Dict, KeysView, List, Set, Tuple, Union
 
 from niltype import Nil, Nilable
 
@@ -9,7 +9,7 @@ from ..errors import DeclarationError, make_already_declared_error, make_invalid
 from ..utils import TypeOrEllipsis, is_ellipsis
 from ._schema import GenericSchema, Schema
 
-__all__ = ("DictSchema", "DictProps", "optional",)
+__all__ = ("DictSchema", "DictProps", "make_required", "optional",)
 
 
 class optional:
@@ -25,6 +25,12 @@ class optional:
     def __repr__(self) -> str:
         return f"optional({self._key!r})"
 
+    def __eq__(self, other: Any) -> bool:
+        return isinstance(other, self.__class__) and (self._key == other.key)
+
+    def __hash__(self) -> int:
+        return hash((self._key,))
+
 
 class DictProps(Props):
     @property
@@ -69,6 +75,7 @@ class DictSchema(Schema[DictProps]):
         return self.props.keys[key][0]
 
     def __add__(self, /, other: "DictSchema") -> "DictSchema":
+        assert isinstance(other, Schema)
         self_keys = self.props.keys if (self.props.keys is not Nil) else {}
         other_keys = other.props.keys if (other.props.keys is not Nil) else {}
         merged_keys = {**self_keys, **other_keys}
@@ -78,3 +85,38 @@ class DictSchema(Schema[DictProps]):
         if self.props.keys is Nil:
             return {}.keys()
         return self.props.keys.keys()
+
+
+def make_required(schema: DictSchema, keys: Union[Set[str], List[str], None] = None) -> DictSchema:
+    if not isinstance(schema, DictSchema):
+        message = f"Inappropriate type of schema {schema!r} ({type(schema)!r})"
+        raise DeclarationError(message)
+
+    actual_keys_list = list(schema.keys())
+
+    if not actual_keys_list:
+        message = "DictSchema must not be empty"
+        raise DeclarationError(message)
+    else:
+        for key in actual_keys_list:
+            if is_ellipsis(key):
+                message = "DictSchema must not be relaxed"
+                raise DeclarationError(message)
+
+    if keys:
+        if not isinstance(keys, (set, list)):
+            message = f"Inappropriate type of keys {keys!r} ({type(keys)!r})"
+            raise DeclarationError(message)
+        for key in keys:
+            if key not in actual_keys_list:
+                message = f"Nonexisting key {key!r}"
+                raise DeclarationError(message)
+
+    keys_to_be_required = list(keys) if keys else actual_keys_list
+
+    updated_keys = {}
+    props_keys = {} if (schema.props.keys is Nil) else schema.props.keys
+    for key, (val, is_optional) in props_keys.items():
+        updated_keys[key] = (val, False if key in keys_to_be_required else is_optional)
+
+    return schema.__class__(schema.props.update(keys=updated_keys))
